@@ -40,6 +40,8 @@ class View():
         self.root = root
         self.controller = controller
         self.pref_win_statut = False
+        self.help_win_statut = False
+        self.about_win_statut = False
         # contrôle l'état des fenêtre uniques (aide, à propos, préférences)
         self.menubar = Menu(root)
         self.filemenu = Menu(self.menubar, tearoff=0)
@@ -51,7 +53,7 @@ class View():
                                   command=self.tree_refresh)
         self.filemenu.add_separator()
         self.filemenu.add_command(label='Préférences',
-                                  command=self.call_preferences_window)
+                                  command=self.create_preferences_window)
         self.filemenu.add_separator()
         self.filemenu.add_command(label='Quiter',
                                   accelerator='ctrl+q',
@@ -124,177 +126,35 @@ class View():
         self.tv.bind("<Double-1>", self.on_double_click)
         self.tv.bind("<ButtonRelease-3>", self.on_right_click)
 
+        self.get_saved_prefs()
+        self.tree_initialise()
+        
+
+
+    def get_saved_prefs(self):
+        """This function recalls prefs stored values"""
+        self.prefs=self.controller.open_saved_prefs()
+        self.prefs_path=self.prefs['path']
+        self.prefs_separator=self.prefs['separator']
+        self.prefs_notation=self.prefs['notation_format']
+        
+
+    def tree_initialise(self):
+        """This function init tree data and displays it"""
+        if self.prefs_path == '':
+            pass
+        else:
+            self.frame0.text.set(self.prefs_path)
+            self.get_saved_prefs()
+            self.tree_refresh()
+            
+
     def collapse_nodes(self, value):
         """Treview function, collapse/open all nodes"""
         for tree_index in range(len(self.model.wordsDict)):
             self.tv.item(tree_index, open=value)
 
 
-# gestion des racourcis clavier
-
-    def select_folder(self, event):
-        """Command function for keyboard shortcuts, calls path selection function."""
-        self.choose_folder()
-
-    def refresh_treeview(self, event):
-        """Command function for keyboard shortcuts, calls treeview refresh function."""
-        self.tree_refresh()
-
-    def close_programm(self, event):
-        """Command function for keyboard shortcuts, calls programm quit function."""
-        self.controller.quit()
-
-
-# création des fenêtres singleton
-
-    def create_about_window(self):
-        """About Window Creation.Singleton mecanism"""
-        a = AboutWindow(self.root)
-
-    def create_help_window(self):
-        """Help Window Creation.Singleton mecanism"""
-        a = HelpWindow(self.root)
-
-    def call_preferences_window(self):
-        """Calls the Preferences window creation function. Manual single window creation."""
-        if self.pref_win_statut is False:
-            self.create_preferences_window()
-
-    def create_preferences_window(self):
-        """Preferences Window creation."""
-        self.preferences_check = True
-        self.preferences_window = Toplevel()
-        self.preferences_window.wm_title("Préférences")
-        self.preferences_window.protocol('WM_DELETE_WINDOW',
-                                         self.close_pref)
-        self.buttonChooseDefaultPath = Button(
-                            self.preferences_window,
-                            text='Choisir un dossier a indexer par défaut',
-                            command=self.choose_default)
-
-        self.buttonChooseDefaultPath.pack()
-        self.default_path = StringVar('')
-        self.l1 = Label(self.preferences_window,
-                        textvariable=self.default_path)
-        self.l1.pack()
-        self.l2 = Label(self.preferences_window,
-                       text="Séparateur par défaut")
-        self.l2.pack()
-        self.separator = StringVar()
-        R1 = Radiobutton(self.preferences_window,
-                         text="espace",
-                         variable=self.separator,
-                         value=" ",
-                         command=self.do_nothing)
-        R1.pack(anchor=CENTER)
-        R2 = Radiobutton(self.preferences_window,
-                         text="virgule",
-                         variable=self.separator,
-                         value=",",
-                         command=self.do_nothing)
-        R2.pack(anchor=CENTER)
-        self.l3 = Label(self.preferences_window,
-                       text="Format des fichiers de notation")
-        self.l3.pack()
-        self.notation_format = StringVar()
-        R3 = Radiobutton(self.preferences_window,
-                         text="Lylipond",
-                         variable=self.notation_format,
-                         value=".ly ",
-                         command=self.do_nothing)
-        R3.pack(anchor=CENTER)
-        R4 = Radiobutton(self.preferences_window,
-                         text="Musescore",
-                         variable=self.notation_format,
-                         value=".mscz",
-                         command=self.do_nothing)
-        R4.pack(anchor=CENTER)
-        R5 = Radiobutton(self.preferences_window,
-                         text="Sibélius",
-                         variable=self.notation_format,
-                         value=".sib",
-                         command=self.do_nothing)
-        R5.pack(anchor=CENTER)
-        R6 = Radiobutton(self.preferences_window,
-                         text="Final",
-                         variable=self.notation_format,
-                         value=".musx",
-                         command=self.do_nothing)
-        R6.pack(anchor=CENTER)
-        self.l4 = Label(self.preferences_window,
-                       text="Position des fichiers de notation")
-        self.l4.pack()
-        self.notation_position = BooleanVar()
-        R7 = Radiobutton(self.preferences_window,
-                         text="Identique au fichier PDF",
-                         variable=self.notation_position,
-                         value=True,
-                         command=self.do_nothing)
-        R7.pack(anchor=CENTER)
-        R8 = Radiobutton(self.preferences_window,
-                         text="Tous dans le même dossier",
-                         variable=self.notation_position,
-                         value=False,
-                         command=self.choose_default_notation)
-        R8.pack(anchor=CENTER)
-        self.default_notation_path = StringVar('')
-        self.l1 = Label(self.preferences_window,
-                        textvariable=self.default_notation_path)
-        self.l1.pack()
-        self.buttonResetPreferences = Button(self.preferences_window,
-                                             text='Reset',
-                                             command=self.do_nothing)
-        self.buttonResetPreferences.pack(side=RIGHT)
-        self.buttonDiscardPreferences = Button(self.preferences_window,
-                                               text='Annuler',
-                                               command=self.do_nothing)
-        self.buttonDiscardPreferences.pack(side=RIGHT)
-        self.buttonSavePreferences = Button(self.preferences_window,
-                                            text='Sauvegarder',
-                                            command=self.do_nothing)
-        self.buttonSavePreferences.pack(side=RIGHT)
-        R1.invoke()
-        R3.invoke()
-        R7.invoke()
-
-    def close_pref(self):
-        """Manual single window Preferences Window destruction."""
-        self.pref_win_statut = False
-        self.preferences_window.destroy()
-
-    def choose_default(self):
-        """This function calls system specific select path mecanism and sets new value to path global variable"""
-        newPath = self.get_directory()
-        self.default_path.set(newPath)
-
-    def do_nothing(self):
-        """This functino does nothing. Used as Default value for a new widget command function."""
-        pass
-
-# Test sur la sélection par la souris
-    def prout(self, event):
-        """This funtion """
-        print("selected:" + self.tv.focus())
-
-    def prouti(self, caca):
-        print("Open")
-
-    def prouta(self, caca):
-        print("Close")
-
-# Gestion de la souris
-    def on_double_click(self, event):
-        """Function called by Mouse double click, calls open pdf file function."""
-        item = self.tv.identify("item", event.x, event.y)
-        self.controller.run_file(self.tv.item(item)["values"][1])
-
-    def on_right_click(self, event):
-        """Function called by mouse right click, calls opend notation file function."""
-        item = self.tv.identify("item", event.x, event.y)
-        path = self.tv.item(item)["values"][1][:-4]+'.ly'
-        self.controller.run_file(path)
-
-
 # Cette fonction efface le contenu de l'arbre
     def tree_delete(self, size):
             if size > 0:
@@ -318,14 +178,15 @@ class View():
                                            self.model.wordsDict[key][list_index]['path']])
                 tree_index += 1
 
-    def tree_refresh(self):  # oh copie de code de choose_folder
+    def tree_refresh(self):  # oh copie dself.get_saved_prefs()e code de choose_folder
         treeSize = len(self.model.wordsDict)
         path = self.frame0.text.get()
         recursive = self.checkbox_value.get()
         self.model.scan_repertory(path, recursive)
         self.tree_delete(treeSize)
         self.tree_repopulate()
-
+        
+# fontions de la fenêtre principale
     def get_directory(self):
             givenPath = filedialog.askdirectory()
             if givenPath is not None:
@@ -340,6 +201,65 @@ class View():
         self.tree_delete(treeSize)
         self.tree_repopulate()
 
+# gestion des racourcis clavier
+    def select_folder(self, event):
+        """Command function for keyboard shortcuts, calls path selection function."""
+        self.choose_folder()
+
+    def refresh_treeview(self, event):
+        """Command function for keyboard shortcuts, calls treeview refresh function."""
+        self.tree_refresh()
+
+    def close_programm(self, event):
+        """Command function for keyboard shortcuts, calls programm quit function."""
+        self.controller.quit()
+
+# Test sur la sélection par la souris
+    def prout(self, event):
+        """This funtion """
+        print("selected:" + self.tv.focus())
+
+    def prouti(self, caca):
+        print("Open")
+
+    def prouta(self, caca):
+        print("Close")
+
+# Gestion de la souris
+    def on_double_click(self, event):
+        """Function called by Mouse double click, calls open pdf file function."""
+        item = self.tv.identify("item", event.x, event.y)
+        self.controller.run_file(self.tv.item(item)["values"][1])
+
+    def on_right_click(self, event):
+        """Function called by mouse right click, calls opend notation file function."""
+        item = self.tv.identify("item", event.x, event.y)
+        path = self.tv.item(item)["values"][1][:-4]+'.ly'
+        self.controller.run_file(path)
+
+# création des sous-fenêtres 
+    def create_about_window(self):
+        """About Window Creation.Singleton mecanism"""
+        if self.about_win_statut is False:
+            self.about_win_statut = True
+            about_window = AboutWindow(self.root)
+
+    def create_help_window(self):
+        """Help Window Creation"""
+        if self.help_win_statut is False:
+            self.help_win_statut is True
+            help_window = HelpWindow(self.root)
+
+    def create_preferences_window(self):
+        """User preferences window creation"""
+        if self.pref_win_statut is False:
+            self.pref_win_statut = True
+            self.prefs = PreferencesWindow(self.root, self.controller, self)
+
+    def do_nothing(self):
+        """This functino does nothing. Used as Default value for a new widget command function."""
+        pass
+
 
 class Menubar():
     def __init(self, arg):
@@ -369,64 +289,183 @@ class Menubar():
         self.root.config(menu=self.menubar)
 
 
-class AboutWindow():  # motif singleton copié de https://python-3-patterns-idioms-test.readthedocs.io/en/latest/Singleton.html
-    class __OnlyOne:
-        def __init__(self, arg):
-            self.val = arg
-            self.filewin = Toplevel(self.val)
-            text = Text(self.filewin)
-            text.insert(INSERT,
+class PreferencesWindow():
+    def __init__(self, root, controller, view):
+        self.root = root
+        self.controller = controller
+        self.view = view
+        self.preferences_window = Toplevel(self.root)
+        self.preferences_window.wm_title("Préférences")
+       
+        self.buttonChooseDefaultPath = Button(
+                            self.preferences_window,
+                            text='Choisir un dossier a indexer par défaut',
+                            command=self.choose_default)
+
+        self.buttonChooseDefaultPath.pack()
+        self.path_label = StringVar()
+
+        self.l1 = Label(self.preferences_window,
+                        textvariable=self.path_label)
+        self.l1.pack()
+        self.l2 = Label(self.preferences_window,
+                       text="Séparateur par défaut")
+        self.l2.pack()
+        self.separator = StringVar()
+        self.R1 = Radiobutton(self.preferences_window,
+                         text="espace",
+                         variable=self.separator,
+                         value=" ",
+                         command=lambda: self.set_temp_prefs('', None))
+        self.R1.pack(anchor=CENTER)
+        self.R2 = Radiobutton(self.preferences_window,
+                         text="virgule",
+                         variable=self.separator,
+                         value=",",
+                         command=lambda: self.set_temp_prefs(',', None))
+        self.R2.pack(anchor=CENTER)
+        self.l3 = Label(self.preferences_window,
+                       text="Format des fichiers de notation")
+        self.l3.pack()
+        self.notation_format = StringVar()
+        self.R3 = Radiobutton(self.preferences_window,
+                         text="Lylipond",
+                         variable=self.notation_format,
+                         value=".ly ",
+                         command=lambda: self.set_temp_prefs(None, '.ly'))
+        self.R3.pack(anchor=CENTER)
+        self.R4 = Radiobutton(self.preferences_window,
+                         text="Musescore",
+                         variable=self.notation_format,
+                         value=".mscz",
+                         command=lambda: self.set_temp_prefs(None, '.mscz'))
+        self.R4.pack(anchor=CENTER)
+        self.R5 = Radiobutton(self.preferences_window,
+                         text="Sibélius",
+                         variable=self.notation_format,
+                         value=".sib",
+                         command=lambda: self.set_temp_prefs(None, '.sib'))
+        self.R5.pack(anchor=CENTER)
+        self.R6 = Radiobutton(self.preferences_window,
+                         text="Finale",
+                         variable=self.notation_format,
+                         value=".musx",
+                         command=lambda: self.set_temp_prefs(None, '.musx'))
+        self.R6.pack(anchor=CENTER)
+        self.buttonResetPreferences = Button(self.preferences_window,
+                                             text='Rétablir valeurs par défaut',
+                                             command=self.reset_prefs)
+        self.buttonResetPreferences.pack(side=RIGHT)
+        self.buttonDiscardPreferences = Button(self.preferences_window,
+                                               text='Annuler',
+                                               command=self.close_prefs)
+        self.buttonDiscardPreferences.pack(side=RIGHT)
+        self.buttonSavePreferences = Button(self.preferences_window,
+                                            text='Sauvegarder',
+                                            command=self.save_temp_prefs)
+        self.buttonSavePreferences.pack(side=RIGHT)
+        self.prefs=self.controller.open_saved_prefs()
+        self.prefs_path=self.prefs['path']
+        self.prefs_separator=self.prefs['separator']
+        self.prefs_notation=self.prefs['notation_format']
+        self.display_saved_prefs()
+        self.path_label.set(self.prefs_path)
+        self.invoke_prefs()
+
+    def get_saved_prefs(self):
+        """This function recalls stored values"""
+        self.prefs=self.controller.open_saved_prefs()
+        self.prefs_path=self.prefs['path']
+        self.prefs_separator=self.prefs['separator']
+        self.prefs_notation=self.prefs['notation_format']
+
+    def invoke_prefs(self):
+        """This functions sets the radio buttons to current prefs values"""
+        if self.prefs_separator == '':
+            self.R1.invoke()
+        elif self.prefs_separator == ',':
+            self.R2.invoke()
+        if self.prefs_notation == '.ly':
+            self.R3.invoke()
+        elif self.prefs_notation == '.mscz':
+            self.R4.invoke()
+        elif self.prefs_notation == '.sib':
+            self.R5.invoke()
+        elif self.prefs_notation == '.musx':
+            self.R6.invoke()
+
+    def choose_default(self):
+        """This function calls system specific select path mecanism and displays new path value, not saved"""
+        newPath = self.get_directory()
+        self.path_label.set(newPath)
+        self.prefs_path=newPath
+
+    def reset_prefs(self):
+        """This function dispays default values, not saved"""
+        self.prefs_path=''
+        self.set_temp_prefs('', '.ly')
+        self.invoke_prefs()
+
+    def set_temp_prefs(self, separator, notation):
+        if separator != None:
+            self.prefs_separator=separator
+        if notation != None:
+            self.prefs_notation=notation
+
+    def save_temp_prefs(self):
+        self.prefs={'path': self.prefs_path , 'separator':self.prefs_separator,
+                    'notation_format':self.prefs_notation}
+        self.controller.save_new_user_prefs(self.prefs)
+        self.close_prefs()
+
+    def display_saved_prefs(self):
+        """ This function asks curent prefs to controller and display them"""
+        self.get_saved_prefs()
+        self.path_label.set(self.prefs_path)
+        self.invoke_prefs()
+
+    def close_prefs(self):
+        """Manual single window Preferences Window destruction."""
+        self.view.pref_win_statut = False
+        self.preferences_window.destroy()
+
+class AboutWindow():  
+    def __init__(self, arg):
+        self.val = arg
+        self.filewin = Toplevel(self.val)
+        text = Text(self.filewin)
+        text.insert(INSERT,
 """\
-Didacto \n
+Didacto o.1.4dev\n
 Un projet développé pour vous par Marco de Freitas en confinement partiel.
 """)
-            text.config(wrap=WORD, state=DISABLED, padx=10, pady=10)
-            text.pack()
-    instance = None
-
-    def __init__(self, arg):
-        if not AboutWindow.instance:
-            AboutWindow.instance = AboutWindow.__OnlyOne(arg)
-        else:
-            AboutWindow.instance.val = arg
+        text.config(wrap=WORD, state=DISABLED, padx=10, pady=10)
+        text.pack()
+ 
 
 
 class HelpWindow():
-    class __OnlyOne:
-        def __init__(self, arg):
-            self.val = arg
-            self.filewin = Toplevel(self.val)
-            text = Text(self.filewin)
-            text.insert(INSERT,
+    def __init__(self, arg):
+        self.root = arg
+        self.filewin = Toplevel(self.root)
+        text = Text(self.filewin)
+        text.insert(INSERT,
 """\
-Principe - Didacto est un logiciel d'aide à l'enseignement instrumental, qui facilite l'organisation didactique d'un répertoire authentique. \n
-Pour l'utiliser il convient d'abord d'assigner à chaque oeuvre de votre répertoire enseigné un certrain nombre de mots-clés par exemple: débutant, technique, etc. \n
+Principe - Didacto est un logiciel d'aide à l'enseignement instrumental, qui facilite l'organisation didactique d'un répertoire d'exercices, d'études, ou authentique. \n
+Didacto travail sur les partition au format pdf. Il faut donc au préalablre, lors de la création de vos pdf à partir d'un logiciel de notation ou à partir d'un logiciel de notation,
+informer le champs mots-clés.
 Fonctionnement - Choisir un répertoire à indexer. Didacto affiche une liste des mots-clés utilisés. Un clique sur un mot clé ouvre la liste des morceaux contenant ce mots clef\n
+Un double-clique sur le nom du fichier ouvre le pdf. Un clique droit ouvre le fichier source de votre logiciel de notation.
 """)
-            text.insert(END,
+        text.insert(END,
 """\
 En cliquant sur un mot-clés, Didacto affiche les titres des partitions. Double-cliquer sur le titre ouvre le pdf correspondant. Un clique droit ouvre le fichier Lylipond (.ly) correxpondant.
 """)
-            text.config(wrap=WORD, state=DISABLED)
-            text.pack()
-
-    instance = None
-
-    def __init__(self, arg):
-        if not HelpWindow.instance:
-            HelpWindow.instance = HelpWindow.__OnlyOne(arg)
-        else:
-            HelpWindow.instance.val = arg
+        text.config(wrap=WORD, state=DISABLED)
+        self.buttonQuit = Button(self.filewin,
+                                        text='Fermer',
+                                        command=self.quit)
+        self.buttonQuit.pack(side=RIGHT)
+        text.pack()
 
 
-class SingletonWindow():
-    class __OnlyOne:
-        def __init__(self, arg, content):
-            content(arg)
-    instance = None
-
-    def __init__(self, arg, content):
-        if not SingletonWindow.instance:
-            SingletonWindow.instance = SingletonWindow.__OnlyOne(arg, content)
-        else:
-            HelpWindow.instance.val = arg
